==> ModuleXtender-0.1.16.zip: ModuleXtender-0.1.16/method.install.php <==
<?php
if (!isset($gCms)) exit;

	/*---------------------------------------------------------
	   Install()
	   When your module is installed, you may need to do some
	   setup. Typical things that happen here are the creation
	   and prepopulation of database tables, database sequences,
	   permissions, preferences, etc.
	   	   
	   For information on the creation of database tables,
	   check out the ADODB Data Dictionary page at
	   http://phplens.com/lens/adodb/docs-datadict.htm
	   
	   This function can return a string in case of any error,
	   and CMS will not consider the module installed.
	   Successful installs should return FALSE or nothing at all.
	  ---------------------------------------------------------*/
		
		// Typical Database Initialization
		$db =& $gCms->GetDb();
		
		// mysql-specific, but ignored by other database
		$taboptarray = array('mysql' => 'TYPE=MyISAM');
		$dict = NewDataDictionary($db);
		
		
		// TABLES CREATION
		
        // table schema description
        $flds = "
			modulename C(255) KEY,
			installed I,
			isactive I,
			xtendversion C(255),
			modulefriendlyname C(255),
			options C(255)
			";

		// create it. This should do error checking, but I'm a lazy sod.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_xtendedmodules",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		//$db->CreateSequence(cms_db_prefix()."module_modulextender_seq");
		
		// TABLE RELATIONS
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			title  C(255),
			modulename C(255),
			rel_type C(255),
			rel_id I,
			is_visible I,
			have_sub I,
			position I,
			is_filter I,
			is_sortable I,
			have_column I,
			is_unique I,
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_relations",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_relations_seq");
		
		// TABLE RELATIONS LINKS
		//######################
				
		// table schema description
        $flds = "
			id I KEY,
			modulename C(255),
			rel_code C(255),
			rel_id I,
			module_id C(255)
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_relations_link",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_relations_link_seq");		
		
		// TABLE CATEGORIES
		//#################
		
        // table schema description
        $flds = "
			id I KEY,
			title C(255),
			position I
			";

		// create it. This should do error checking, but I'm a lazy sod.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_categories",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_categories_seq");
		
		// TABLE OPTIONS
		//##############
				
		// table schema description
        $flds = "
			id I KEY,
			title C(255),
			position I,
			category_id I
			";

		// create it. This should do error checking, but I'm a lazy sod.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_options",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_options_seq");
		
		
		// TABLE DOCUMENTS
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			modulename C(255),
			module_id I,
			type C(255),
			title C(255),
			file C(255),
			position I
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_documents",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_documents_seq");	
		
		// TABLE LINKS
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			modulename C(255),
			module_id I,
			title C(255),			
      url XL,
			is_new_window I,
			position I
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_links",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_links_seq");	
		
		// permissions
		
		// Preferences
		
		 	$this->SetPreference('countries_imagepath','/modules/ModuleXtender/images/countries');
	  
			$this->SetPreference('fe.general','fe.general');
			$this->SetPreference('fe.documents','fe.documents');
			$this->SetPreference('fe.images','fe.images');
			$this->SetPreference('fe.pages','fe.pages');
			$this->SetPreference('fe.categories','fe.categories');
			
		// Templates
			$this->SetTemplate('fe.documents', $this->GetTemplateFromFile('fe.documents'));
			$this->SetTemplate('fe.images', $this->GetTemplateFromFile('fe.images'));
			$this->SetTemplate('fe.general', $this->GetTemplateFromFile('fe.general'));
			$this->SetTemplate('fe.pages', $this->GetTemplateFromFile('fe.pages'));
			$this->SetTemplate('fe.categories', $this->GetTemplateFromFile('fe.categories'));
			
        // StyleSheet
        
            $stylesheet = new stdClass();
			$stylesheet->name = $this->GetName() . '.css';
			$stylesheet->value = $this->GetTemplateFromFile('style.css');
			$stylesoperations = $gCms->GetStylesheetOperations();		
			$stylesoperations->InsertStylesheet($stylesheet);

		// put mention into the admin log
		$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('installed',$this->GetVersion()));
		
?>

==> ModuleXtender-0.1.20.zip: ModuleXtender-0.1.20/method.install.php <==
<?php
if (!isset($gCms)) exit;

	/*---------------------------------------------------------
	   Install()
	   When your module is installed, you may need to do some
	   setup. Typical things that happen here are the creation
	   and prepopulation of database tables, database sequences,
	   permissions, preferences, etc.
	   	   
	   For information on the creation of database tables,
	   check out the ADODB Data Dictionary page at
	   http://phplens.com/lens/adodb/docs-datadict.htm
	   
	   This function can return a string in case of any error,
	   and CMS will not consider the module installed.
	   Successful installs should return FALSE or nothing at all.
	  ---------------------------------------------------------*/
		
		// Typical Database Initialization
		$db =& $gCms->GetDb();
		
		// mysql-specific, but ignored by other database
		$taboptarray = array('mysql' => 'TYPE=MyISAM');
		$dict = NewDataDictionary($db);
		
		
		// TABLES CREATION
		
        // table schema description
        $flds = "
			modulename C(255) KEY,
			installed I,
			isactive I,
			xtendversion C(255),
			modulefriendlyname C(255),
			options C(255)
			";

		// create it. This should do error checking, but I'm a lazy sod.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_xtendedmodules",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		//$db->CreateSequence(cms_db_prefix()."module_modulextender_seq");
		
		// TABLE RELATIONS
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			title  C(255),
			modulename C(255),
			rel_type C(255),
			rel_id I,
			is_visible I,
			have_sub I,
			position I,
			is_filter I,
			is_sortable I,
			have_column I,
			is_unique I,
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_relations",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_relations_seq");
		
		// TABLE RELATIONS LINKS
		//######################
				
		// table schema description
        $flds = "
			id I KEY,
			modulename C(255),
			rel_code C(255),
			rel_id I,
			module_id C(255)
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_relations_link",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_relations_link_seq");		
		
		// TABLE CATEGORIES
		//#################
		
        // table schema description
        $flds = "
			id I KEY,
			title C(255),
			position I
			";

		// create it. This should do error checking, but I'm a lazy sod.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_categories",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_categories_seq");
		
		// TABLE OPTIONS
		//##############
				
		// table schema description
        $flds = "
			id I KEY,
			title C(255),
			position I,
			category_id I
			";

		// create it. This should do error checking, but I'm a lazy sod.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_options",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_options_seq");
		
		
		// TABLE DOCUMENTS
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			modulename C(255),
			module_id I,
			type C(255),
			title C(255),
			file C(255),
			position I
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_documents",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_documents_seq");	
		
		// TABLE LINKS
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			modulename C(255),
			module_id I,
			title C(255),			
      url XL,
			is_new_window I,
			position I
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_links",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_links_seq");	
		
		
		// TABLE Associated category
		//################
				
		// table schema description
        $flds = "
			id I KEY,
			type C(255),
			modulename C(255),
			category_id I,
			position I
			";

		// create it.
		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_modulextender_related_categories",
				$flds, $taboptarray);
		$dict->ExecuteSQLArray($sqlarray);

		// create a sequence
		$db->CreateSequence(cms_db_prefix()."module_modulextender_related_categories_seq");	
		
		// permissions
		
		// Preferences
		
		 	$this->SetPreference('countries_imagepath','/modules/ModuleXtender/images/countries');
	  
			$this->SetPreference('fe.general','fe.general');
			$this->SetPreference('fe.documents','fe.documents');
			$this->SetPreference('fe.images','fe.images');
			$this->SetPreference('fe.pages','fe.pages');
			$this->SetPreference('fe.categories','fe.categories');
			
		// Templates
			$this->SetTemplate('fe.documents', $this->GetTemplateFromFile('fe.documents'));
			$this->SetTemplate('fe.images', $this->GetTemplateFromFile('fe.images'));
			$this->SetTemplate('fe.general', $this->GetTemplateFromFile('fe.general'));
			$this->SetTemplate('fe.pages', $this->GetTemplateFromFile('fe.pages'));
			$this->SetTemplate('fe.categories', $this->GetTemplateFromFile('fe.categories'));
			
        // StyleSheet
        
            $stylesheet = new stdClass();
			$stylesheet->name = $this->GetName() . '.css';
			$stylesheet->value = $this->GetTemplateFromFile('style.css');
			$stylesoperations = $gCms->GetStylesheetOperations();		
			$stylesoperations->InsertStylesheet($stylesheet);

		// put mention into the admin log
		$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('installed',$this->GetVersion()));
		
?>
